@@ -10,7 +10,7 @@ from ibmdbpy4nps.ae import NZFunGroupedApply
 dsn ={
     "database":"customer_churn",
      "port" :5480,
-     "host" : "169.63.46.17",
+     "host" : "xxx",
      "securityLevel":0,
      "logLevel":0
 
@@ -21,7 +21,6 @@ dsn ={
 #dsn='bank'
 
 
-
 idadb = IdaDataBase(dsn, 'admin', 'password' )
 
 
