@@ -4,6 +4,6 @@ from ibmdbpy4nps.ae.install import NZInstall
 
 idadb = IdaDataBase('weather', 'admin', 'password')
 
-nzinstall = NZInstall(idadb, package_name='scikit-learn')
+nzinstall = NZInstall(idadb, package_name='pandas')
 print(nzinstall.getResultCode())
 
